select
    row_number() over (order by o.or_id desc) as "pos",
    os.os_name as "ordersystem",
    case
      when s.st_type = 'K' then 'COPY'
      when s.st_type = 'E' then 'FORM'
      when s.st_type = 'S' then 'SCAN'
      else s.st_type
    end as "circulation",
    cast(o.or_id as text) as "ordernumber",
    replace(split_part(o.or_tan, ':', -1), '/', '%2F') as "transactionid",
    replace(split_part(o.or_tan, ':', -1), '/', '%2F') as "externaltransactionnumber",
    o.or_when as "ordertime",
    s.st_when as "lastactivitytime",
    case
      when o.or_status in (5,17) then s.st_when
      else null
    end as "supplytime",
    case
      when sup.it_type = 'N' then 'INTERNAL'
      when sup.it_type = 'M' then 'INTERNAL'
      when sup.it_type = 'I' then 'INTERNAL'
      when sup.it_type = 'X' then 'DISABLED'
      when sup.it_type = 'V' then 'EXTERNAL'
      else 'INTERNAL'
    end as "deliveryscope",
    case
      when s.st_del_type = 0 then 'NONE'
      when s.st_del_type = 1 then 'FAX'
      when s.st_del_type = 2 then 'WWW'
      when s.st_del_type = 3 then 'FTP'
      when s.st_del_type = 4 then 'FTP'
      when s.st_del_type = 5 then 'EMAIL'
      when s.st_del_type = 6 then 'PRINT'
      when s.st_del_type = 7 then 'NET'
      when s.st_del_type = 8 then 'POST'
      when s.st_del_type = 9 then 'INHOUSE'
      when s.st_del_type = 10 then 'COLLECT'
      when s.st_del_type = 11 then 'NETWORK'
      when s.st_del_type = 12 then 'DISTANCELEARNING'
      when s.st_del_type = 13 then 'PRINTINGSYSTEM'
      else 'UNDEFINED'
    end as "deliverystyle",
    case
      when req.it_type = 'N' then 'INTERNAL'
      when req.it_type = 'M' then 'INTERNAL'
      when req.it_type = 'I' then 'INTERNAL'
      when req.it_type = 'X' then 'DISABLED'
      when req.it_type = 'V' then 'EXTERNAL'
      else 'INTERNAL'
    end as "notifymethod",
    case
      when s.st_del_nf_type = 0 then 'NONE'
      when s.st_del_nf_type = 1 then 'EMAIL'
      when s.st_del_nf_type = 2 then 'POST'
      when s.st_del_nf_type = 3 then 'INHOUSE'
      when s.st_del_nf_type = 4 then 'FAX'
      else 'UNDEFINED'
    end as "notifystyle",
    cast(o.or_status as text) as "status",
    NULL as "substatus",
    sup.it_isil as "supplierisil",
    req.it_isil as "requesterisil",
    s.st_bennr as "clientid",
    s.st_ben1 as "clientname",
    o.or_note as "clientcomment",
    s.st_zuskosten as "maxcost",
    s.st_del_fetch_location as "pickuplocation",
    s.st_locname as "pickupcode",
    s.st_del_email as "clientemail",
    s.ST_DEL_NF_IM1 || chr(10) || s.ST_DEL_NF_IM2 || chr(10) || s.ST_DEL_NF_IM3 as "clientaddress",
    replace(o.or_ext_user_id,'/','%2F') as "externalrequester",
    s.st_del_mail_name2 || chr(10) || s.st_del_mail_street || chr(10) || s.st_del_mail_zip || ' ' || s.st_del_mail_city as "externaladdress",
    case
      when s.st_type = 'K' then '2'
      when s.st_type = 'S' then '2'
      when s.st_type = 'E' then '9'
      else NULL
    end as "priority",
    case
      when e.time IS NULL then -1
      else current_date - cast(e.time as date)
    end as "deliveryage",
    o.or_num_pages as "pages",
    s.st_itm_art_author as "author",
    s.st_itm_art_title as "title",
    s.st_itm_title as "intitle",
    s.st_itm_publ_date_comp as "year",
    case
      when position('Band' in s.st_itm_vol_issue) > 0 then trim(regexp_substr(s.st_itm_vol_issue, 'Band(.*)Heft.*', 1, 1, NULL, 1))
      else s.st_itm_vol_issue
    end as "volume",
    case
      when position('Heft' in s.st_itm_vol_issue) > 0 then trim(regexp_substr(s.st_itm_vol_issue, '.*Heft(.*)', 1, 1, NULL, 1))
      else NULL
    end as "issue",
    s.st_itm_pagination as "pagination",
    s.st_itm_publisher as "publisher",
    s.st_itm_publ_place as "publisherplace",
    s.st_itm_isn as "isbn",
    '' as "issn",
    upper(s.st_itm_ver_ref_src) as "source",
    s.st_itm_uniq_id1 as "sourceid",
    e1.message as "doi",
    e2.ref as "directdelivery",
    e3.ref as "deliveryhash"
from orders o
    inner join ordersys os on o.or_os_id = os.os_id
    inner join stages s on o.or_id = s.st_or_id and o.or_seqno = s.st_seqno
    inner join institutions req on s.st_src_inst = req.it_id
    inner join institutions sup on s.st_dest_inst = sup.it_id
    left outer join event e on cast(o.or_id as text) = e.ordernumber and e.type = 'transaction' and e.code = 'transaction-success'
    left outer join event e1 on cast(o.or_id as text) = e1.ordernumber and e1.type = 'requestform' and e1.code = 'doi'
    left outer join event e2 on cast(o.or_id as text) = e2.ordernumber and e2.type = 'ack' and e2.code = 'membership-dd'
    left outer join event e3 on cast(o.or_id as text) = e3.ordernumber and e3.type = 'ack' and e3.code = 'hash'
