select
  "Bibliothek",
  "Quelle",
  "Nummer",
  "ISSN/ISBN",
  "Titel",
  "nehmende Bibliothek",
  "Anzahl"
from (
  select
    dest.it_isil as "Bibliothek",
    s.st_itm_ver_ref_src as "Quelle",
    s.st_itm_uniq_id1 as "Nummer",
    s.st_itm_isn as "ISSN/ISBN",
    s.st_itm_title as "Titel",
    src.it_isil as "nehmende Bibliothek",
    count(*) as "Anzahl"
  from
    orders o
    inner join stages s on o.or_id = s.st_or_id and o.or_seqno = s.st_seqno
    inner join institutions dest on s.st_dest_inst = dest.it_id
    inner join institutions src on s.st_src_inst = src.it_id
  where
    s.st_when between to_date(:startdate,'YYYY-MM-DD') and to_date(:enddate,'YYYY-MM-DD')
    and dest.it_isil in ('DE-38M', 'DE-5N')
  group by
    dest.it_isil,
    s.st_itm_ver_ref_src,
    s.st_itm_uniq_id1,
    s.st_itm_isn,
    s.st_itm_title,
    src.it_isil
  union
  select
    sup.zf10isil as "Bibliothek",
    upper(regexp_substr(t.zf8quelle,'[^$]+')) as "Quelle",
    t.zf8titelid as "Nummer",
    trim(case
      when t.zf8isbn IS NULL then ''
      else t.zf8isbn
    end ||
    case
      when t.zf8issn IS NULL then ''
      else t.zf8issn
    end) as "ISSN/ISBN",
    t.zf8titel as "Titel",
    req.zf10isil as "nehmende Bibliothek",
    count(*) as "Anzahl"
  from
    zf1medien m
    inner join zf8titel t on m.zf1bestellid = t.zf8bestellid
    inner join zf6status stat on m.zf1bestellid = stat.zf6bestellid and m.zf1lfd = stat.zf6lfd
    inner join zf10bibl sup on stat.zf6sigelaktuell_id = sup.zf10id
    inner join zf10bibl req on m.zf1sigelnb_id = req.zf10id
  where
    m.zf1bstype2 = 'C'
    and stat.zf6date between to_date(:startdate,'YYYY-MM-DD') and to_date(:enddate,'YYYY-MM-DD')
    and sup.zf10isil in ('DE-38M', 'DE-5N')
  group by
    sup.zf10isil,
    upper(regexp_substr(t.zf8quelle,'[^$]+')),
    t.zf8titelid,
    trim(case
      when t.zf8isbn IS NULL then ''
      else t.zf8isbn
    end ||
    case
      when t.zf8issn IS NULL then ''
      else t.zf8issn
    end),
    t.zf8titel,
    req.zf10isil
)
order by
  "Bibliothek" asc,
  "Anzahl" desc
